@@ -1,4 +1,5 @@
 import pytest
+
 from xonsh.completers.pip import PIP_RE, PIP_LIST_RE
 
 
@@ -33,6 +34,9 @@ def test_pip_list_re(line):
         "![thewholepipandpaboodle uninstall",
         "$[littlebopip show",
         "!(boxpip uninstall",
+        "pipx",
+        "vim pip_",
+        "pip_",
     ],
 )
 def test_pip_list_re1(line):
